pydevDAG._decorations._decorations module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._decorations package »

# pydevDAG._decorations._decorations module

## pydevDAG._decorations._decorations

Tools to decorate networkx graphs in situ, i.e., as constructed rather than as read from a textual file.

class `pydevDAG._decorations._decorations.` `Decorator`

  Bases: `object`

  Decorate graph elements with attributes.

  classmethod `decorate_edges`(graph, properties)

    Decorate the graph.

    Parameters: | graph (DiGraph) – the graph properties (dict of property name -> graph element -> value) – a dict of properties

  classmethod `decorate_nodes`(graph, properties)

    Decorate the graph.

    Parameters: | graph (DiGraph) – the graph properties (dict of property name -> graph element -> value) – a dict of properties

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._decorations package »